# Objective 1
## Title: Collect and utilize accurate and disaggregated data as a basis for evidence-based policies
## Associated actions
- a. Elaborate and implement a comprehensive strategy for improving migration data at local, national, regional and global levels
- b. Improve international comparability and compatibility of migration statistics and national data systems
- c. Develop a global programme to build and enhance national capacities in data collection, analysis and dissemination
- d. Collect, analyse and use data on the effects and benefits of migration
- e. Support further development of and collaboration between existing global and regional databases and depositories
- f. Establish and strengthen regional centres for research and training on migration or migration observatories
- g. Improve national data collection by integrating migration-related topics in national censuses, as early as practicable
- h. Conduct household, labour force and other surveys to collect information on the social and economic integration of migrants
- i. Enhance collaboration between State units responsible for migration data and national statistical offices
- j. Develop and use country-specific migration profiles
- k. Cooperate with relevant stakeholders in countries of origin, transit and destination

# Objective 2
## Title: Minimize the adverse drivers and structural factors that compel people to leave their country of origin
## Associated actions
- a. Promote the implementation of the 2030 Agenda for Sustainable Development
- b. Invest in programmes that accelerate States' fulfilment of the Sustainable Development Goals
- c. Establish or strengthen mechanisms to monitor and anticipate the development of risks and threats
- d. Invest in sustainable development at local and national levels in all regions
- e. Invest in human capital development
- f. Strengthen collaboration between humanitarian and development actors
- g. Account for migrants in national emergency preparedness and response
- h. Strengthen joint analysis and sharing of information to better map, understand, predict and address migration movements
- i. Develop adaptation and resilience strategies to sudden-onset and slow-onset natural disasters
- j. Integrate displacement considerations into disaster preparedness strategies and promote cooperation with neighbouring and other relevant countries
- k. Harmonize and develop approaches and mechanisms at subregional and regional levels
- l. Develop coherent approaches to address the challenges of migration movements in the context of sudden-onset and slow-onset natural disasters

# Objective 3
## Title: Provide accurate and timely information at all stages of migration
## Associated actions
- a. Launch and publicize a centralized and publicly accessible national website
- b. Promote and improve systematic bilateral, regional and international cooperation and dialogue
- c. Establish open and accessible information points along relevant migration routes
- d. Provide newly arrived migrants with targeted, gender-responsive, child-sensitive, accessible and comprehensive information and legal guidance
- e. Promote multi-lingual, gender-responsive and evidence-based information campaigns

# Objective 4
## Title: Ensure that all migrants have proof of legal identity and adequate documentation
## Associated actions
- a. Improve civil registry systems
- b. Harmonize travel documents in line with the specifications of the International Civil Aviation Organization
- c. Ensure adequate, timely, reliable and accessible consular documentation to our nationals residing in other countries
- d. Facilitate access to personal documentation
- e. Strengthen measures to reduce statelessness
- f. Review and revise requirements to prove nationality at service delivery centres
- g. Build upon existing practices at the local level that facilitate participation in community life

# Objective 5
## Title: Enhance availability and flexibility of pathways for regular migration
## Associated actions
- a. Develop human rights-based and gender-responsive bilateral, regional and multilateral labour mobility agreements
- b. Facilitate regional and cross-regional labour mobility through international and bilateral cooperation arrangements
- c. Review and revise existing options and pathways for regular migration
- d. Develop flexible, rights-based and gender-responsive labour mobility schemes for migrants
- e. Promote effective skills matching in the national economy by involving local authorities and other relevant stakeholders
- f. Foster efficient and effective skills-matching programmes
- g. Develop or build on existing national and regional practices for admission and stay of appropriate duration
- h. Cooperate to identify, develop and strengthen solutions for migrants compelled to leave their countries of origin
- i. Facilitate access to procedures for family reunification for migrants
- j. Expand available options for academic mobility

# Objective 6
## Title: Facilitate Fair And Ethical Recruitment And Safeguard Conditions That Ensure Decent Work
## Associated actions
- a. Promote signature, ratification, accession and implementation of relevant international instruments
- b. Build upon the work of existing bilateral, subregional and regional platforms
- c. Improve regulations on public and private recruitment agencies
- d. Establish partnerships with all relevant stakeholders
- e. Enact and implement national laws that sanction human and labour rights violations
- f. Strengthen the enforcement of fair and ethical recruitment and decent work norms and policies
- g. Develop and strengthen labour migration and fair and ethical recruitment processes
- h. Take measures that prohibit the confiscation or non-consensual retention of work contracts
- i. Provide migrant workers engaged in remunerated and contractual labour with the same labour rights and protections
- j. Ensure migrants working in the informal economy have safe access to effective reporting, complaint, and redress mechanisms
- k. Review relevant national labour laws, employment policies and programmes
- l. Develop and improve national policies and programmes relating to international labour mobility

# Objective 7
## Title: Address and Reduce Vulnerabilities in Migration
## Associated actions
- a. Review relevant policies and practices to ensure they do not create, exacerbate or unintentionally increase vulnerabilities of migrants
- b. Establish comprehensive policies and develop partnerships
- c. Develop gender-responsive migration policies
- d. Review relevant existing labour laws and work conditions
- e. Account for migrant children in national child protection systems
- f. Protect unaccompanied and separated children at all stages of migration
- g. Ensure migrants have access to public or affordable independent legal assistance and representation
- h. Develop accessible and expedient procedures that facilitate transitions from one status to another
- i. Build on existing practices to facilitate access for migrants in an irregular status
- j. Apply specific support measures
- k. Involve local authorities and relevant stakeholders in the identification, referral and assistance of migrants
- l. Develop national policies and programmes to improve national responses

# Objective 8
## Title: Save Lives and Establish Coordinated International Efforts on Missing Migrants
## Associated actions
- a. Develop procedures and agreements on search and rescue of migrants
- b. Review the impacts of migration-related policies and laws to ensure that these do not raise or create the risk of migrants going missing
- c. Enable migrants to communicate with their families without delay to inform them that they are alive
- d. Establish transnational coordination channels
- e. Collect, centralize and systematize data regarding corpses and ensure traceability after burial
- f. Make all efforts, including through international cooperation, to recover, identify and repatriate the remains of deceased migrants

# Objective 9
## Title: Strengthen the transnational response to smuggling of migrants
## Associated actions
- a. Promote ratification, accession and implementation of the Protocol against the Smuggling of Migrants by Land, Sea and Air
- b. Use transnational, regional and bilateral mechanisms to share relevant information and intelligence on smuggling routes
- c. Develop gender-responsive and child-sensitive cooperation protocols along migration routes
- d. Adopt legislative and other measures as may be necessary to establish the smuggling of migrants as a criminal offence
- e. Design, review or amend relevant policies and procedures to distinguish between the crimes of smuggling of migrants and trafficking in persons
- f. Take measures to prevent the smuggling of migrants along the migration cycle in partnership with other States and relevant stakeholders

# Objective 10
## Title: Prevent, Combat And Eradicate Trafficking In Persons In The Context Of International Migration
## Associated actions
- a. Promote, ratification, accession and implementation of the Protocol to Prevent, Suppress and Punish Trafficking in Persons Especially Women and Children
- b. Promote the implementation of the Global Plan of Action to Combat Trafficking in Persons and take into consideration relevant recommendations
- c. Monitor irregular migration routes which may be exploited by human trafficking networks
- d. Share relevant information and intelligence through transnational and regional mechanisms
- e. Apply measures that address the particular vulnerabilities of women, men, girls and boys
- f. Ensure that definitions of trafficking in persons used in legislation, migration policy and planning are in accordance with international law
- g. Strengthen legislation and relevant procedures to enhance prosecution of traffickers, avoid criminalization of migrants
- h. Provide migrants that have become victims of trafficking in persons with protection and assistance
- i. Create national and local information systems and training programmes
- j. Invest in awareness-raising campaigns

# Objective 11
## Title: Manage Borders In An Integrated, Secure And Coordinated Manner
## Associated actions
- a. Enhance international, regional and cross-regional border management cooperation
- b. Establish appropriate structures and mechanisms for effective integrated border management
- c. Review and revise relevant national procedures for border screening, individual assessment and interview processes
- d. Develop technical cooperation agreements
- e. Ensure that child protection authorities are promptly informed and assigned to participate in procedures
- f. Review and revise relevant laws and regulations
- g. Improve cross-border collaboration among neighbouring and other States

# Objective 12
## Title: Strengthen Certainty And Predictability In Migration Procedures For Appropriate Screening, Assessment And Referral
## Associated actions
- a. Increase transparency and accessibility of migration procedures
- b. Develop and conduct intra- and cross-regional specialized human rights and trauma informed trainings
- c. Establish gender-responsive and child-sensitive referral mechanisms
- d. Ensure that migrant children are promptly identified at places of first arrival in countries of transit and destination
- e. Ensure that, in the context of mixed movements, relevant information on rights and obligations

# Objective 13
## Title: Use Migration Detention Only As A Measure Of Last Resort And Work Towards Alternatives
## Associated actions
- a. Use existing relevant human rights mechanisms to improve independent monitoring of migrant detention
- b. Consolidate a comprehensive repository to disseminate best practices of human rights based alternatives to detention
- c. Review and revise relevant legislation, policies and practices related to migration detention
- d. Provide access to justice for all migrants in countries of transit and destination that are or may be subject to detention
- e. Ensure that all migrants in detention are informed about the reasons for their detention
- f. Reduce the negative and potentially lasting effects of detention on migrants
- g. Ensure that all governmental authorities and private actors duly charged with administering immigration detention do so in a way consistent with human rights
- h. Protect and respect the rights and best interests of the child at all times

# Objective 14
## Title: Enhance Consular Protection, Assistance And Cooperation Throughout The Migration Cycle
## Associated actions
- a. Cooperate to build consular capacities
- b. Involve relevant consular and immigration personnel in existing global and regional fora on migration
- c. Conclude bilateral or regional agreements on consular assistance and representation
- d. Strengthen consular capacities in order to identify, protect and assist our nationals abroad who are in a situation of vulnerability
- e. Provide our nationals abroad the opportunity to register with the country of origin
- f. Provide consular support to our nationals through advice

# Objective 15
## Title: Provide access to basic services for migrants
## Associated actions
- a. Enact laws and take measures to ensure that service delivery does not amount to discrimination against migrants
- b. Ensure that cooperation between service providers and immigration authorities does not exacerbate vulnerabilities of irregular migrants
- c. Establish and strengthen holistic and easily accessible service points at local level
- d. Establish or mandate independent institutions at the national or local level
- e. Incorporate the health needs of migrants in national and local health care policies and plans
- f. Provide inclusive and equitable quality education to migrant children and youth

# Objective 16
## Title: Empower Migrants And Societies To Realize Full Inclusion And Social Cohesion
## Associated actions
- a. Promote mutual respect for the cultures, traditions and customs of communities of destination and of migrants
- b. Establish comprehensive and needs-based pre-departure and post-arrival programmes
- c. Develop national short, medium and long term policy goals regarding the inclusion of migrants in societies
- d. Work towards inclusive labour markets and full participation of migrant workers in the formal economy
- e. Empower migrant women by eliminating gender-based discriminatory restrictions
- f. Establish community centres or programmes at the local level to facilitate migrant participation in the receiving society
- g. Capitalize on the skills, cultural and language proficiency of migrants and receiving communities
- h. Support multicultural activities through sports, music, arts, culinary festivals, volunteering and other social events
- i. Promote school environments that are welcoming and safe, and support the aspirations of migrant children

# Objective 17
## Title: Eliminate All Forms Of Discrimination And Promote Evidence-Based Public Discourse To Shape Perceptions Of Migration
## Associated actions
- a. Enact, implement or maintain legislation that penalizes hate crimes and aggravated hate crimes targeting migrants
- b. Empower migrants and communities to denounce any acts of incitement to violence directed towards migrants
- c. Promote independent, objective and quality reporting of media outlets
- d. Establish mechanisms to prevent, detect and respond to racial, ethnic and religious profiling of migrants
- e. Provide migrants, especially migrant women, with access to national and regional complaint and redress mechanisms
- f. Promote awareness-raising campaigns targeted at communities of origin, transit and destination
- g. Engage migrants, political, religious and community leaders, as well as educators and service providers

# Objective 18
## Title: Invest In Skills Development And Facilitate Mutual Recognition Of Skills, Qualifications And Competences
## Associated actions
- a. Develop standards and guidelines for the mutual recognition of foreign qualifications and non-formally acquired skills
- b. Promote transparency of certifications and compatibility of National Qualifications Frameworks
- c. Conclude bilateral, regional or multilateral mutual recognition agreements
- d. Use technology and digitalization to evaluate and mutually recognize skills more comprehensively
- e. Build global skills partnerships amongst countries
- f. Promote inter-institutional networks and collaborative programmes for partnerships between the private sector and educational institutions
- g. Engage in bilateral partnerships and programmes in cooperation with relevant stakeholders
- h. Cooperate with the private sector and employers
- i. Enhance the ability of migrant workers to transition from a job or employer to another
- j. Develop and promote innovative ways to mutually recognize and assess formally and informally acquired skills
- k. Establish screening mechanisms of credentials and offer information to migrants
- l. Cooperate to promote documentation and information tools

# Objective 19
## Title: Create Conditions For Migrants And Diasporas To Fully Contribute To Sustainable Development In All Countries
## Associated actions
- a. Ensure the full and effective implementation of the 2030 Agenda for Sustainable Development and the Addis Ababa Action Agenda
- b. Integrate migration into development planning and sectoral policies at local, national, regional and global levels
- c. Invest in research on the impact of non-financial contributions of migrants and diasporas to sustainable development
- d. Facilitate the contributions of migrants and diasporas to their countries of origin
- e. Develop targeted support programmes and financial products
- f. Provide easily accessible information and guidance
- g. Enable political participation and engagement of migrants in their countries of origin
- h. Promote migration policies that optimize the benefits of diasporas for countries of origin and destination
- i. Cooperate with other States, the private sector and employers organizations to enable migrants and diasporas
- j. Build partnerships between local authorities, local communities, the private sector, diasporas, hometown associations and migrant organizations

# Objective 20
## Title: Minimize the adverse drivers and structural factors that compel people to leave their country of origin
## Associated actions
- a. Promote the implementation of the 2030 Agenda for Sustainable Development
- b. Invest in programmes that accelerate States' fulfilment of the Sustainable Development Goals
- c. Establish or strengthen mechanisms to monitor and anticipate the development of risks and threats
- d. Invest in sustainable development at local and national levels in all regions
- e. Invest in human capital development
- f. Strengthen collaboration between humanitarian and development actors
- g. Account for migrants in national emergency preparedness and response
- h. Strengthen joint analysis and sharing of information to better map, understand, predict and address migration movements
- i. Develop adaptation and resilience strategies to sudden-onset and slow-onset natural disasters
- j. Integrate displacement considerations into disaster preparedness strategies and promote cooperation with neighbouring and other relevant countries
- k. Harmonize and develop approaches and mechanisms at subregional and regional levels
- l. Develop coherent approaches to address the challenges of migration movements in the context of sudden-onset and slow-onset natural disasters

# Objective 21
## Title: Cooperate In Facilitating Safe And Dignified Return And Readmission, As Well As Sustainable Reintegration
## Associated actions
- a. Develop and implement bilateral, regional and multilateral cooperation frameworks and agreements
- b. Promote gender-responsive and child-sensitive return and reintegration programmes
- c. Cooperate on identification of nationals and issuance of travel documents for safe and dignified return and readmission
- d. Foster institutional contacts between consular authorities and relevant officials from countries of origin and destination
- e. Ensure that the return of migrants who do not have the legal right to stay on another State's territory is safe and dignified
- f. Establish or strengthen national monitoring mechanisms on return
- g. Ensure that return and readmission processes involving children are carried out only after a determination of the best interests of the child
- h. Facilitate the sustainable reintegration of returning migrants into community life
- i. Identify and address the needs of the communities to which migrants return

# Objective 22
## Title: Establish Mechanisms For The Portability Of Social Security Entitlements And Earned Benefits
## Associated actions
- a. Establish or maintain non-discriminatory national social protection systems
- b. Conclude reciprocal bilateral, regional or multilateral social security agreements
- c. Integrate provisions on the portability of entitlements and earned benefits into national social security frameworks

# Objective 23
## Title: Strengthen International Cooperation And Global Partnerships For Safe, Orderly And Regular Migration
## Associated actions
- a. Support other States as we collectively implement the Global Compact
- b. Increase international and regional cooperation to accelerate the implementation of the 2030 Agenda for Sustainable Development
- c. Involve and support local authorities in the identification of needs and opportunities for international cooperation for the effective implementation of the Global Compact
- d. Make use of the capacity-building mechanism and build upon other existing instruments to strengthen the capacities of relevant authorities
- e. Conclude bilateral, regional or multilateral mutually beneficial, tailored and transparent partnerships